@echo off
echo.
rem Q2LZ - QDAT/indexing script
set _Pname=LZON
set _Pver=LZON622
set _ID=LZ
set _Sdate=19Jul99
set _Dsp=S
rem Supported file types: DOSVGM
rem (2 to 15 minutes on a 200MHz Pentium)
rem
if (%1) == () goto usage
echo Q2%_ID% - Runs the %_Pver% indexing program automatically on the dataset
echo in targeted QDAT input file %1.Q%_ID% (as written by CRYS) if present,
echo else in %1.QDT, using QDAT/%_Pver% defaults unless specified otherwise
echo.
echo R.Shirley, %_Sdate%
rem
rem *** ITO12 data files created by QDAT are acceptable to %_Pver%
rem
set _Dspn=short
if (%_Dsp%) == (O) set _Dspn=main
set _Dset=%1
if exist %_Dset%.Q%_ID% copy %_Dset%.Q%_ID% QDAT.DAT >nul
if exist %_Dset%.Q%_ID% goto proceed
if exist %_Dset%.QDT copy %_Dset%.QDT QDAT.DAT >nul
if exist %_Dset%.QDT goto proceed
echo.
echo ** Specified input file %1.Q%_ID% (or %1.QDT) not found in this directory
echo ** Cannot proceed with the run - check for mis-typing, etc
echo.
goto end

:proceed
echo.
echo.
echo Running QDAT format conversion program to generate %_Pver% input data file ...
echo.
QDAT
del QDAT.DAT
copy QDAT.OUT %_Dset%.QDO >nul
del QDAT.OUT
:chk_cards
if exist CARDS.OUT goto copy_cards
echo.
echo    ** Can't find QDAT's output file CARDS.OUT from this run
goto failed
:copy_cards
copy CARDS.OUT %_Dset%.%_ID%D >nul
copy CARDS.OUT %_Pname%.DAT >nul
del CARDS.OUT >nul
rem Rename any existing %_Dset%.%_ID%O main output file to %_ID%_OUT.BAK, so
rem as not to confuse it with the output from this run, in case this run fails
if exist %_ID%_OUT.BAK del %_ID%_OUT.BAK >nul
if exist %_Dset%.%_ID%O ren %_Dset%.%_ID%O %_ID%_OUT.BAK >nul
rem and similarly any existing %_Dset%.%_ID%S short output file to %_ID%_SHT.BAK
if exist %_ID%_SHT.BAK del %_ID%_SHT.BAK >nul
if exist %_Dset%.%_ID%S ren %_Dset%.%_ID%S %_ID%_SHT.BAK >nul
rem Delete any pre-existing %_Pver% short output file, since %_Pver% may not
rem overwrite it but just halt, complaining of an "output file error"
if exist %_Pname%.SHT del %_Pname%.SHT >nul
echo.
echo Running %_Pver% indexing program (2 to 15 minutes on a 200MHz Pentium)
echo.
echo To stop the run, press Control-Break, but reply N to "Terminate batch job?"
echo (to have output files renamed and get shown the results up to that point)
%_Pver%
del %_Pname%.DAT

rem Carry out systematic file renaming
:ren_ver
if not exist %_Pname%.VER goto ren_log
if exist %_Dset%.%_ID%V del %_Dset%.%_ID%V >nul
ren %_Pname%.VER %_Dset%.%_ID%V >nul
:ren_log
if not exist %_Pname%.LOG goto ren_sum
if exist %_Dset%.%_ID%G del %_Dset%.%_ID%G >nul
ren %_Pname%.LOG %_Dset%.%_ID%G >nul
:ren_sum
if not exist %_Pname%.SUM goto ren_sht
if exist %_Dset%.%_ID%M del %_Dset%.%_ID%M >nul
ren %_Pname%.SUM %_Dset%.%_ID%M >nul
:ren_sht
if not exist %_Pname%.SHT goto chk_out
if exist %_Dset%.%_ID%S del %_Dset%.%_ID%S >nul
ren %_Pname%.SHT %_Dset%.%_ID%S >nul
:chk_out
if exist %_Pname%.OUT goto ren_out
rem Restore old main & short output files from backup before taking error exit
if exist %_Dset%.%_ID%O goto rest_sbak
if exist %_ID%_OUT.BAK ren %_ID%_OUT.BAK %_Dset%.%_ID%O
:rest_sbak
if exist %_Dset%.%_ID%S goto fail_out
if exist %_ID%_SHT.BAK ren %_ID%_SHT.BAK %_Dset%.%_ID%S
:fail_out
echo.
echo    ** Can't find the main output file %_Pname%.OUT from this run
goto failed
:ren_out
if exist %_Dset%.%_ID%O del %_Dset%.%_ID%O >nul
ren %_Pname%.OUT %_Dset%.%_ID%O >nul

:upd_log
rem Append run-logfile .%_ID%G to dataset-logfile .LOG (leaving backup in .LGK)
if not exist %_Dset%.%_ID%G goto upd_app
if exist %_Dset%.LGK del %_Dset%.LGK >nul
if exist %_Dset%.LOG ren %_Dset%.LOG %_Dset%.LGK
if exist %_Dset%.LGK copy %_Dset%.LGK+%_Dset%.%_ID%G %_Dset%.LOG >nul
if not exist %_Dset%.LGK copy %_Dset%.%_ID%G %_Dset%.LOG >nul

:upd_app
rem Append run-summary .%_ID%M to dataset-summary .SUM (leaving backup in .SMK),
rem sort the updated dataset-summary into descending order of I20 & Merit
rem and update the V/V1 ratios based on the volume now in record one
if not exist %_Dset%.%_ID%M goto disp_sht
if exist %_Dset%.SMK del %_Dset%.SMK >nul
if exist %_Dset%.SUM ren %_Dset%.SUM %_Dset%.SMK
if exist %_Dset%.SMK copy %_Dset%.SMK+%_Dset%.%_ID%M %_Dset%.$$1 >nul
if not exist %_Dset%.SMK copy %_Dset%.%_ID%M %_Dset%.$$1 >nul
if not exist %_Dset%.$$1 goto add_head
sort /R <%_Dset%.$$1 >%_Dset%.$$2
rem Use program VRATIO to update the V/V1 ratios in the sorted summary
if not exist %_Dset%.$$2 goto add_head
VRATIO %_Dset%.$$2 %_Dset%.SUM >nul
del %_Dset%.$$? >nul
:add_head
if exist %_Dset%.SMH del %_Dset%.SMH >nul
rem Use program QHEAD to generate headings file HEADINGS.SUM, so that
rem HEADINGS.SUM need not be copied beforehand into the current directory
QHEAD >nul
rem HEADINGS.SUM should now be present, but its existence tests have been
rem kept anyway, in case of problems
if exist HEADINGS.SUM copy HEADINGS.SUM+%_Dset%.SUM %_Dset%.SMH >nul

:disp_sht
echo Run completed
if (%INDEXEDIT%) == (NONE) goto end
echo.
echo The %_Dspn% output file will now be displayed in an editor.  On exit, this will
echo be followed by an updated summary of all solutions so far for this dataset.
pause
set INDXED=%INDEXEDIT%
if (%INDXED%) == () set INDXED=edit
%INDXED% %_Dset%.%_ID%%_Dsp%
set INDXED=
if exist %_Dset%.SMH goto disp_smh
if exist HEADINGS.SUM goto disp_cont
echo Don't interrupt the run to do it now, but note for future reference that
echo if you make sure that the program QHEAD is present in the CRYSFIRE directory,
echo your summary files will then be displayed with an explanatory heading.
pause
:disp_cont
if exist %_Dset%.SUM goto disp_smh
echo Can't find summary file %_Dset%.SMH or .SUM to display next in the editor,
echo so will have to end the run now, and leave you to check that for yourself
goto end

:disp_smh
rem We can now delete HEADINGS.SUM to reduce the file clutter (it was retained
rem only as a flag to disarm the above QHEAD warning, if present)
if exist HEADINGS.SUM del HEADINGS.SUM >nul
echo The sorted summary file of all indexing solutions found so far by the
echo CRYSFIRE system for dataset %_Dset% will now be displayed in an editor.
pause
set INDXED=%INDEXEDIT%
if (%INDXED%) == () set INDXED=edit
set _EXT=SUM
if exist %_Dset%.SMH set _EXT=SMH
%INDXED% %_Dset%.%_EXT%
set INDXED=
set _EXT=
goto end

:failed
echo    ** so it appears to have failed.
echo.
echo If any error messages are displayed, note them *NOW* while you can see them.
pause
echo    Here are some possibilities for you to check:
echo.
echo 1) If you got an "Out of environment space" message, you have probably
echo    already used up most of your DOS environment allocation, and so
echo    need to increase this to e.g. 1024 or 2048 bytes, using the SHELL
echo    command in CONFIG.SYS (/e parameter - e.g. /e:2048 for 2048 bytes)
echo.
echo    Thus to provide 2048 bytes of environment space, insert the one of the
echo    following "shell=" lines in your CONFIG.SYS file, as appropriate:
echo.
echo    (Windows 95)       shell=C:\WINDOWS\COMMAND.COM C:\WINDOWS /e:2048 /p
echo    (DOS/Windows 3.1)  shell=C:\COMMAND.COM C:\DOS /e:2048 /p
echo.
pause
echo 2) If the message reads "Bad command or file name", one of the scripts or
echo    programs needed couldn't be found.  So check whether the directory that
echo    they are in has been put on your execution PATH in AUTOEXEC.BAT (and of
echo    course whether the files needed are still there in it).
echo 3) If you got an out-of-memory diagnostic, use MEM to check whether you
echo    have enough base-memory free (preferably at least 550K).  If not, try
echo    freeing some up, for example by booting without network drivers.
echo 4) If you ran out of disk space, free some up and try again (5MB free
echo    would be nice).
echo 5) If you've checked all the above, *and* have read CRYSFIRE.DOC, but you're
echo    *still* stuck, email me at R.Shirley@surrey.ac.uk, explaining *clearly*
echo    what happened and attaching the relevant data and output files, and I'll
echo    see what I can do.  But as I get very busy, I can't make any promises.
echo.
echo    Good luck!                                            Robin Shirley
echo.
goto end

:usage
echo Q2%_ID% - Runs the %_Pver% indexing program automatically on the dataset
echo in targeted QDAT input file %%1.Q%_ID% (as written by CRYS) if present,
echo else in %%1.QDT, using QDAT/%_Pver% defaults unless specified otherwise
rem *** LZON-specific
echo (effectively the same format as for ITO12)
echo Typical run time:  2 to 15 minutes on a 200MHz Pentium
rem ***
echo.
echo usage    Q2%_ID% {datafile}
echo.
echo          where {datafile} is the base name of the %%1.Q%_ID% targeted QDAT
echo                input file (or %%1.QDT QDAT input file)
echo                (without its .Q%_ID% or .QDT extension)
echo.
echo   The same {datafile} name is used to identify all files in the run:
echo.
echo      QDAT targeted input file   = {datafile}.Q%_ID%
echo        or QDAT input file       = {datafile}.QDT
echo      QDAT output listing file   = {datafile}.QDO
echo      %_Pver% input data file    = {datafile}.%_ID%D
echo      %_Pver% main output file   = {datafile}.%_ID%O
echo      %_Pver% short output file  = {datafile}.%_ID%S
echo      %_Pver% input verification = {datafile}.%_ID%V
echo      %_Pver% solutions-log      = {datafile}.%_ID%G
echo      %_Pver% solutions-summary  = {datafile}.%_ID%M
echo.
pause
echo   The solutions log and summary are also appended to the log and summary
echo   files for that dataset: {datafile}.LOG and {datafile}.SUM respectively.
echo   {datafile}.SUM is then sorted into descending order of I20 and Merit.
echo   (The minimum levels for inclusion vary for different indexing programs,
echo   but are typically I20 above 15 and Merit above approx 7 to 9)
echo.
echo   At the end of the indexing run, first the short output file, and then
echo   the sorted solutions summary, are displayed using the editor specified
echo   in environmental variable INDEXEDIT (default: MSDOS EDIT).
echo.
echo   Thus the following files provide a record of all runs for this dataset,
echo   after updating with the current run as described above:
echo.
echo      dataset solutions-log         = {datafile}.LOG
echo      dataset solutions-summary     = {datafile}.SUM (sorted)
echo      dataset solutions-display     = {datafile}.SMH (headed summary)
echo.
echo      old dataset solutions-log     = {datafile}.LGK (backup)
echo      old dataset solutions-summary = {datafile}.SMK (backup)
echo.
echo   R.Shirley, %_Sdate%
echo.
:end
set _Dset=
set _Dspn=
set _Dsp=
set _Sdate=
set _ID=
set _Pver=
set _Pname=
