@echo off
echo.
rem RUNTP - Indexing script
set _Pname=TAUP
set _Pver=TAUP32
set _ID=TP
set _Sdate=19Jul99
set _Dsp=O
rem Supported file types: DOVGM
rem (Typically a few seconds down to orthorhombic on a 200MHz Pentium,
rem over an hour down to monoclinic, and forever down to triclinic)
rem
if (%1) == () goto usage
echo RUN%_ID% - Runs the %_Pver% indexing program automatically on the dataset
echo in input file %1.%_ID%D (written, for example, by QDAT, and then perhaps
echo hand-edited to try to improve on the default results)
echo.
echo R.Shirley, %_Sdate%
rem
set _Dspn=short
if (%_Dsp%) == (O) set _Dspn=main
set _Dset=%1
if exist %_Dset%.%_ID%D goto proceed
echo.
echo ** Specified input file %_Dset%.%_ID%D not found in this directory
echo ** Cannot proceed with the run - check for mis-typing, etc
echo.
goto end

:proceed
copy %_Dset%.%_ID%D %_Pname%.DAT >nul
rem Rename any existing %_Dset%.%_ID%O main output file to %_ID%_OUT.BAK, so
rem as not to confuse it with the output from this run, in case this run fails
if exist %_ID%_OUT.BAK del %_ID%_OUT.BAK >nul
if exist %_Dset%.%_ID%O ren %_Dset%.%_ID%O %_ID%_OUT.BAK >nul
rem *** TAUP-specific omission (no short output file to backup, etc)
rem ***
echo.
rem *** TAUP-specific
echo Running Taupin's index-permutation powder indexing program
echo (Typically 10-20 seconds down to orthorhombic on a 200MHz Pentium,
echo over an hour down to monoclinic, and forever down to triclinic)
rem ***
echo.
echo To stop the run, press Control-Break, but reply N to "Terminate batch job?"
echo (to have output files renamed and get shown the results up to that point)
%_Pver%
del %_Pname%.DAT

rem Carry out systematic file renaming
rem *** TAUP-specific
if exist %_Pname%.APL copy %_Pname%.APL %_Dset%.TPL >nul
if exist %_Pname%.APL del %_Pname%.APL >nul
if exist %_Pname%.RST copy %_Pname%.RST %_Dset%.TPR >nul
if exist %_Pname%.RST del %_Pname%.RST >nul
if exist %_Pname%.CEL copy %_Pname%.CEL %_Dset%.TPC >nul
if exist %_Pname%.CEL del %_Pname%.CEL >nul
rem ***
:ren_ver
rem *** TAUP-specific
if not exist %_Pname%.$$$ goto ren_log
if exist %_Dset%.%_ID%V del %_Dset%.%_ID%V >nul
ren %_Pname%.$$$ %_Dset%.%_ID%V >nul
rem ***
:ren_log
rem *** TAUP-specific
rem Test for existence of loghead-file and use this as criterion for proceeding
if not exist %_Pname%.LGH goto ren_sum
rem Now for some fancy footwork - sorting the log-body and calculating
rem its Vratios, and then assembling the complete logfile
rem 1) Ensure that any existing %_Dset%.$$? are deleted
if exist %_Dset%.$$1 del %_Dset%.$$1 >nul
if exist %_Dset%.$$2 del %_Dset%.$$2 >nul
rem 2) Sort the log-body into descending order
if exist %_Pname%.LGB sort /R <%_Pname%.LGB >%_Dset%.$$1
rem 3) Use program VRATIO to compute V/V1 ratios in the sorted log-body
if exist %_Dset%.$$1 VRATIO %_Dset%.$$1 %_Dset%.$$2 >nul
rem 4) Assemble the sorted logfile, or at least as much as is available
if exist %_Dset%.%_ID%G del %_Dset%.%_ID%G >nul
copy %_Pname%.LGH+%_Dset%.$$2+%_Pname%.LGT %_Dset%.%_ID%G >nul
rem 5) If this went OK, delete the associated workfiles (otherwise skip)
if not exist %_Dset%.%_ID%G goto ren_sum
if exist %_Dset%.$$1 del %_Dset%.$$1 >nul
if exist %_Dset%.$$2 del %_Dset%.$$2 >nul
if exist %_Pname%.LGH del %_Pname%.LGH >nul
if exist %_Pname%.LGB del %_Pname%.LGB >nul
if exist %_Pname%.LGT del %_Pname%.LGT >nul
rem ***
:ren_sum
rem *** TAUP-specific
if not exist %_Pname%.SUM goto chk_out
rem Some similar but briefer work on the summary file - sorting and
rem calculating its Vratios
rem 1) Ensure that any existing %_Dset%.$$$ is deleted
if exist %_Dset%.$$$ del %_Dset%.$$$ >nul
rem 2) Sort the raw summary into descending order (already tested for existence)
sort /R <%_Pname%.SUM >%_Dset%.$$$
rem 3) Use program VRATIO to compute V/V1 ratios in the sorted summary
rem (check for existence first and skip if not, leaving any evidence untouched)
if not exist %_Dset%.$$$ goto chk_out
VRATIO %_Dset%.$$$ %_Dset%.%_ID%M >nul
rem 4) Assuming this went OK, delete the associated workfiles
del %_Dset%.$$$ >nul
del %_Pname%.SUM >nul
rem ***
:ren_sht
rem *** TAUP-specific omission (no short output file)
rem ***
:chk_out
if exist %_Pname%.OUT goto ren_out
rem Restore old main & short output files from backup before taking error exit
if exist %_Dset%.%_ID%O goto rest_sbak
if exist %_ID%_OUT.BAK ren %_ID%_OUT.BAK %_Dset%.%_ID%O
:rest_sbak
rem *** TAUP-specific omission (no short output file)
rem ***
:fail_out
echo.
echo    ** Can't find the main output file %_Pname%.OUT from this run
goto failed
:ren_out
if exist %_Dset%.%_ID%O del %_Dset%.%_ID%O >nul
ren %_Pname%.OUT %_Dset%.%_ID%O >nul

:upd_log
rem Append run-logfile .%_ID%G to dataset-logfile .LOG (leaving backup in .LGK)
if not exist %_Dset%.%_ID%G goto upd_app
if exist %_Dset%.LGK del %_Dset%.LGK >nul
if exist %_Dset%.LOG ren %_Dset%.LOG %_Dset%.LGK
if exist %_Dset%.LGK copy %_Dset%.LGK+%_Dset%.%_ID%G %_Dset%.LOG >nul
if not exist %_Dset%.LGK copy %_Dset%.%_ID%G %_Dset%.LOG >nul

:upd_app
rem Append run-summary .%_ID%M to dataset-summary .SUM (leaving backup in .SMK),
rem sort the updated dataset-summary into descending order of I20 & Merit
rem and update the V/V1 ratios based on the volume now in record one
if not exist %_Dset%.%_ID%M goto disp_sht
if exist %_Dset%.SMK del %_Dset%.SMK >nul
if exist %_Dset%.SUM ren %_Dset%.SUM %_Dset%.SMK
if exist %_Dset%.SMK copy %_Dset%.SMK+%_Dset%.%_ID%M %_Dset%.$$1 >nul
if not exist %_Dset%.SMK copy %_Dset%.%_ID%M %_Dset%.$$1 >nul
if not exist %_Dset%.$$1 goto add_head
sort /R <%_Dset%.$$1 >%_Dset%.$$2
rem Use program VRATIO to update the V/V1 ratios in the sorted summary
if not exist %_Dset%.$$2 goto add_head
VRATIO %_Dset%.$$2 %_Dset%.SUM >nul
del %_Dset%.$$? >nul
:add_head
if exist %_Dset%.SMH del %_Dset%.SMH >nul
rem Use program QHEAD to generate headings file HEADINGS.SUM, so that
rem HEADINGS.SUM need not be copied beforehand into the current directory
QHEAD >nul
rem HEADINGS.SUM should now be present, but its existence tests have been
rem kept anyway, in case of problems
if exist HEADINGS.SUM copy HEADINGS.SUM+%_Dset%.SUM %_Dset%.SMH >nul

:disp_sht
echo Run completed
if (%INDEXEDIT%) == (NONE) goto end
echo.
echo The %_Dspn% output file will now be displayed in an editor.  On exit, this will
echo be followed by an updated summary of all solutions so far for this dataset.
pause
set INDXED=%INDEXEDIT%
if (%INDXED%) == () set INDXED=edit
%INDXED% %_Dset%.%_ID%%_Dsp%
set INDXED=
if exist %_Dset%.SMH goto disp_smh
if exist HEADINGS.SUM goto disp_cont
echo Don't interrupt the run to do it now, but note for future reference that
echo if you make sure that the program QHEAD is present in the CRYSFIRE directory,
echo your summary files will then be displayed with an explanatory heading.
pause
:disp_cont
if exist %_Dset%.SUM goto disp_smh
echo Can't find summary file %_Dset%.SMH or .SUM to display next in the editor,
echo so will have to end the run now, and leave you to check that for yourself
goto end

:disp_smh
rem We can now delete HEADINGS.SUM to reduce the file clutter (it was retained
rem only as a flag to disarm the above QHEAD warning, if present)
if exist HEADINGS.SUM del HEADINGS.SUM >nul
echo The sorted summary file of all indexing solutions found so far by the
echo CRYSFIRE system for dataset %_Dset% will now be displayed in an editor.
pause
set INDXED=%INDEXEDIT%
if (%INDXED%) == () set INDXED=edit
set _EXT=SUM
if exist %_Dset%.SMH set _EXT=SMH
%INDXED% %_Dset%.%_EXT%
set INDXED=
set _EXT=
goto end

:failed
echo    ** so it appears to have failed.
echo.
echo If any error messages are displayed, note them *NOW* while you can see them.
pause
echo    Here are some possibilities for you to check:
echo.
echo 1) If you got an "Out of environment space" message, you have probably
echo    already used up most of your DOS environment allocation, and so
echo    need to increase this to e.g. 1024 or 2048 bytes, using the SHELL
echo    command in CONFIG.SYS (/e parameter - e.g. /e:2048 for 2048 bytes)
echo.
echo    Thus to provide 2048 bytes of environment space, insert the one of the
echo    following "shell=" lines in your CONFIG.SYS file, as appropriate:
echo.
echo    (Windows 95)       shell=C:\WINDOWS\COMMAND.COM C:\WINDOWS /e:2048 /p
echo    (DOS/Windows 3.1)  shell=C:\COMMAND.COM C:\DOS /e:2048 /p
echo.
pause
echo 2) If the message reads "Bad command or file name", one of the scripts or
echo    programs needed couldn't be found.  So check whether the directory that
echo    they are in has been put on your execution PATH in AUTOEXEC.BAT (and of
echo    course whether the files needed are still there in it).
echo 3) If you got an out-of-memory diagnostic, use MEM to check whether you
echo    have enough base-memory free (preferably at least 550K).  If not, try
echo    freeing some up, for example by booting without network drivers.
echo 4) If you ran out of disk space, free some up and try again (5MB free
echo    would be nice).
echo 5) If you've checked all the above, *and* have read CRYSFIRE.DOC, but you're
echo    *still* stuck, email me at R.Shirley@surrey.ac.uk, explaining *clearly*
echo    what happened and attaching the relevant data and output files, and I'll
echo    see what I can do.  But as I get very busy, I can't make any promises.
echo.
echo    Good luck!                                            Robin Shirley
echo.
goto end

:usage
echo RUN%_ID% - Runs the %_Pver% indexing program automatically on the dataset
echo in input file %%1.%_ID%D (written, for example, by QDAT, and then perhaps
echo hand-edited to try to improve on the default results)
rem *** TAUP-specific
echo (Typically a few seconds down to orthorhombic on a 200MHz Pentium,
echo over an hour down to monoclinic, and forever down to triclinic)
rem ***
echo.
echo usage    RUN%_ID% {datafile}
echo.
echo          where {datafile} is the base name of the %%1.%_ID%D input file
echo                (without its .%_ID%D extension)
echo.
rem TAUP-specific
pause
rem ***
echo   The same {datafile} name is used to identify all files in the run:
echo.
echo      %_Pver% input data file     = {datafile}.%_ID%D
echo      %_Pver% main output file    = {datafile}.%_ID%O
rem *** TAUP-specific
rem echo      %_Pver% short output file  = {datafile}.%_ID%S
rem ***
echo      %_Pver% cells output file   = {datafile}.TPC  (=TAUP.CEL cells list)
echo      %_Pver% input verification  = {datafile}.TPV  (=TAUP.$$$ input copy)
echo      %_Pver% run-restart file    = {datafile}.TPR  (=TAUP.RST restart unit)
echo      %_Pver% least-squares file  = {datafile}.TPL  (=TAUP.APL for Appleman prog)
echo                                                   (Obtained only if L flag set)
echo      %_Pver% input verification  = {datafile}.%_ID%V
echo      %_Pver% solutions-log       = {datafile}.%_ID%G
echo      %_Pver% solutions-summary   = {datafile}.%_ID%M
echo.
rem The following comments have been copied verbatim from the program:
rem
rem      OPEN (LP,FILE='TAUP.OUT')
rem      OPEN (INPUT,FILE='TAUP.DAT')
rem      OPEN (ISCRAT,FILE='TAUP.$$$')
rem      OPEN (IPREST,FILE='TAUP.RST')
rem      OPEN (IPUNCH,FILE='TAUP.CEL')
rem      OPEN (ILEAST,FILE='TAUP.APL')
rem
rem  'INPUT' IS THE NORMAL CARD INPUT UNIT
rem  'ISCRAT' IS A SCRATCH DRUM OR DISK UNIT ( TO CONTAIN A COPY OF THE
rem             INPUT DATA )
rem  'IPREST' IS THE UNIT ON WHICH RESTART DATA WILL BE WRITEN OR PUNCHED;
rem  'IRREST' IS THE UNIT ON WHICH RESTART DATA WILL BE READ;
rem              TWO PRACTICAL CASES OCCUR
rem               1) IF RESTART DATA ARE PUNCHED AND READ AS CARDS, THEN
rem                  'IPREST' SHOULD REFER TO PUNCH, AND 'IRREST' SHOULD
rem                  BE EQUAL TO 'ISCRAT' ( SINCE 'INPUT' IS COPIED ON
rem                  'ISCRAT' FOR CONTROL AND LISTING )
rem               2) IF RESTART DATA ARE STORED ON PERMANENT DISK STORAGE,
rem                  THEN 'IPREST' AND 'IRREST' CAN BE EQUATED (AND THEN
rem                  THE 'PWMAIN' ROUTINE WILL PERFORM A REWIND SO THAT
rem                  THE STORAGE WILL BE UPDATED )
rem  'IPUNCH' IS THE UNIT ON WHICH RESULTS WILL BE PUNCHED (OR STORED)
rem  'ILEAST' IS THE UNIT ON WHICH RESULTS WILL BE STORED FOR LEAST SQUARE
rem           REFINEMENT BY APPLEMAN'S PROGRAM.
rem
rem F77 OPEN call added, to define channel 6 as file TAUP.OUT
rem F77 OPEN calls added, to define channels INPUT, ISCRAT,
rem F77 IPREST(=IRREST), IPUNCH & ILEAST respectively as files TAUP.DAT,
rem F77 TAUP.$$$, TAUP.RST, TAUP.CEL & TAUP.LSQ, in working dir
rem
rem With TAUP v3.2c, TAUP.LGH (log-head), TAUP.LGB (unsorted log-body),
rem TAUP.LGT (log-tail) and TAUP.SUM (unsorted summary) files are also created,
rem and may be left around if the run is interrupted and the RUNTP or RUNTP
rem script not allowed to complete its sorting, combining and renaming.
pause
echo   The solutions log and summary are also appended to the log and summary
echo   files for that dataset: {datafile}.LOG and {datafile}.SUM respectively.
echo   {datafile}.SUM is then sorted into descending order of I20 and Merit.
echo   (The minimum levels for inclusion vary for different indexing programs,
echo   but are typically I20 above 15 and Merit above approx 7 to 9)
echo.
echo   At the end of the indexing run, first the short output file, and then
echo   the sorted solutions summary, are displayed using the editor specified
echo   in environmental variable INDEXEDIT (default: MSDOS EDIT).
echo.
echo   Thus the following files provide a record of all runs for this dataset,
echo   after updating with the current run as described above:
echo.
echo      dataset solutions-log         = {datafile}.LOG
echo      dataset solutions-summary     = {datafile}.SUM (sorted)
echo      dataset solutions-display     = {datafile}.SMH (headed summary)
echo.
echo      old dataset solutions-log     = {datafile}.LGK (backup)
echo      old dataset solutions-summary = {datafile}.SMK (backup)
echo.
echo   R.Shirley, %_Sdate%
echo.
:end
set _Dset=
set _Dspn=
set _Dsp=
set _Sdate=
set _ID=
set _Pver=
set _Pname=
